@@ -22,10 +22,10 @@
 #ifndef QAPT_PACKAGE_H
 #define QAPT_PACKAGE_H
 
-#include <QtCore/QFlags>
-#include <QtCore/QUrl>
-#include <QtCore/QDateTime>
-#include <QtCore/QVariantMap>
+#include <QFlags>
+#include <QUrl>
+#include <QDateTime>
+#include <QVariantMap>
 
 #include <apt-pkg/pkgcache.h>
 
@@ -257,8 +257,7 @@ public:
     * Returns the date when Canonical's support of the package ends.
     *
     * \return The date that the package is supported until. If it is not
-    *         supported now, then it will return an empty QString. The date
-    *         will be localized in the "month year" format.
+    *         supported now, then it will return an invalid date.
     */
     QDateTime supportedUntil() const;
 
@@ -309,6 +308,27 @@ public:
     */
     qint64 availableInstalledSize() const;
 
+/**
+    * Returns the amount of hard drive space that this package takes up
+    * when installed.
+    * If the package is installed, then it is the size of the currently
+    * installed version. Otherwise, it is the size of the candidate
+    * version.
+    * This is human-unreadable, so KDE applications may wish to run this
+    * through the KFormat().formatByteSize() function to get a
+    * localized, human-readable number.
+    *
+    * Returns -1 on error.
+    *
+    * @return The installed size of the package
+    *
+    * @see currentInstalledSize()
+    * @see availableInstalledSize()
+    *
+    * @since 3.1
+    */
+    qint64 installedSize() const;
+
    /**
     * Returns the download size of the package archive in bytes.
     * This is human-unreadable, so KDE applications may wish to run this
