@@ -21,12 +21,13 @@
 
 #include "workerinstallprogress.h"
 
-#include <QtCore/QStringBuilder>
-#include <QtCore/QStringList>
-#include <QtCore/QTextCodec>
+#include <QStringBuilder>
+#include <QStringList>
+#include <QTextCodec>
 #include <QDebug>
 
 #include <apt-pkg/error.h>
+#include <apt-pkg/install-progress.h>
 
 #include <errno.h>
 #include <sys/statvfs.h>
@@ -34,6 +35,7 @@
 #include <sys/wait.h>
 #include <sys/fcntl.h>
 #include <pty.h>
+#include <unistd.h>
 
 #include <iostream>
 #include <stdlib.h>
@@ -107,7 +109,8 @@ pkgPackageManager::OrderResult WorkerInstallProgress::start(pkgPackageManager *p
         // close pipe we don't need
         close(readFromChildFD[0]);
 
-        res = pm->DoInstallPostFork(readFromChildFD[1]);
+        APT::Progress::PackageManagerProgressFd progress(readFromChildFD[1]);
+        res = pm->DoInstallPostFork(&progress);
 
         // dump errors into cerr (pass it to the parent process)
         _error->DumpErrors();
